@@ -1,4 +1,5 @@
-/* GnomeMeeting -- A Video-Conferencing application
+
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -12,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -63,7 +64,7 @@
  * PRE          : /
  */
 static gint compare_func (gconstpointer a, 
-	      gconstpointer b);
+			  gconstpointer b);
 
 
 static void resolve_callback (AvahiServiceResolver *r,
@@ -96,14 +97,14 @@ static void client_callback (AvahiClient *c,
 			     AvahiClientState state, 
 			     void *userdata);
 
-/* Browser classi declaration */
+/* Browser class declaration */
 class GMZeroconfBrowser
 {
 
 public:
 
   /* DESCRIPTION  : / 
-   * BEHAVIOR     : ZeroconfBrowse constructor :
+   * BEHAVIOR     : ZeroconfBrowser constructor :
    *		    * initialization of the thread
    *		    * initialization of the discovery zeroconf session
    * PRE          : /
@@ -112,7 +113,7 @@ public:
 
 
   /* DESCRIPTION  : / 
-   * BEHAVIOR     : ZeroconfBrowse destructor.
+   * BEHAVIOR     : ZeroconfBrowser destructor.
    *		    Releases the discovery zeroconf session.
    * PRE          : /
    */
@@ -169,7 +170,7 @@ private:
   GSList *contacts;
 };
 
-GMZeroconfBrowser *zcb = NULL;
+static GMZeroconfBrowser *zcb = NULL;
 
 
 /* Implementation of the callbacks */
@@ -204,7 +205,7 @@ resolve_callback (AvahiServiceResolver *r,
 {
   GMZeroconfBrowser *zero = (GMZeroconfBrowser *) userdata;
   
-  g_return_if_fail (zero != NULL & r != NULL);
+  g_return_if_fail (zero != NULL && r != NULL);
   
   zero->ResolveCallback (r,
 			 interface,
@@ -296,6 +297,7 @@ gnomemeeting_zero_addressbook_get_contacts (GmAddressbook *addressbook,
 					    gchar *fullname,
 					    gchar *url,
 					    gchar *categorie,
+					    gchar *location,
 					    gchar *speeddial)
 {
   GSList *l = NULL;
@@ -310,9 +312,8 @@ gnomemeeting_zero_addressbook_get_contacts (GmAddressbook *addressbook,
   gchar *down_lcfullname = NULL;
   gchar *down_url = NULL;
   gchar *down_lcurl = NULL;
-  
-  if (!zcb)
-    return NULL;
+
+  g_return_val_if_fail (zcb != NULL, NULL);
   
   if (addressbook) {
     
@@ -382,19 +383,7 @@ gnomemeeting_zero_addressbook_get_contacts (GmAddressbook *addressbook,
       /* Match ? */
       if (match) {
 
-	fc = gmcontact_new ();
-
-	fc->fullname = g_strdup (lc->fullname);
-	fc->categories = g_strdup (lc->categories);
-	fc->url = g_strdup (lc->url);
-	fc->location = g_strdup (lc->location);
-	fc->speeddial = g_strdup (lc->speeddial);
-	fc->comment = g_strdup (lc->comment);
-	fc->software = g_strdup (lc->software);
-	fc->email = g_strdup (lc->email);
-	fc->state = lc->state;
-	fc->video_capable = lc->video_capable;
-
+	fc = gmcontact_copy (lc);
 	f = g_slist_append (f, (gpointer) fc);
       }
 
@@ -444,15 +433,16 @@ GMZeroconfBrowser::~GMZeroconfBrowser ()
 
   /* Cleanup things */
   if (h323_sb)
-    avahi_service_browser_free(h323_sb);
+    avahi_service_browser_free (h323_sb);
+
   if (sip_sb)
-    avahi_service_browser_free(sip_sb);
+    avahi_service_browser_free (sip_sb);
     
   if (client)
-    avahi_client_free(client);
+    avahi_client_free (client);
 
   if (glib_poll)
-    avahi_glib_poll_free(glib_poll);
+    avahi_glib_poll_free (glib_poll);
 
 }
 
@@ -481,8 +471,7 @@ GMZeroconfBrowser::ResolveCallback (AvahiServiceResolver *r,
     
     PTRACE (1, "AVAHI\tFailed to resolve service '" << 
 	    name << "' of type '" << type << "' in domain '" << domain <<"'.");
-  }
-  else {
+  } else {
     
     char a [128];
     char *t = NULL;
@@ -512,11 +501,11 @@ GMZeroconfBrowser::ResolveCallback (AvahiServiceResolver *r,
      * in the contact list */
     if (tmp_list && tmp_list->data) {
       
-      gmcontact_delete ((GmContact *) tmp_list->data);
-      tmp_list->data = contact;
+      g_slist_remove (contacts, GM_CONTACT (tmp_list->data));
+      gmcontact_delete (GM_CONTACT (tmp_list->data));
     }
     
-    contact->state = 0;
+    contact->state = CONTACT_AVAILABLE;
     for (txt_tmp = txt; txt_tmp; txt_tmp = txt_tmp->next) {
 
       char *key = NULL;
@@ -532,20 +521,15 @@ GMZeroconfBrowser::ResolveCallback (AvahiServiceResolver *r,
       else if (key && !strcmp ((const char *) key, "software"))
 	contact->software = g_strdup ((char *)value);
       else if (key && !strcmp((const char *) key, "state"))
-	contact->state = (atoi ((const char *) value) == 2 ? 1 : 0);
+	contact->state = (atoi ((const char *) value) == 2
+			  ?CONTACT_BUSY
+			  :CONTACT_AVAILABLE);
 
       /* Ignore other keys */
       avahi_free (key);
       avahi_free (value);
     }
     
-    /* If the list wasn't NULL it means that we found the contact 
-     * so we just updated his info (email/location etc...) but we don't add it 
-     * because it was already in the list.
-     */
-    if (tmp_list)
-      return;
-    
     /* Add the new contact in the contacts list. */
     contacts = g_slist_append (contacts, (gpointer) contact);
     
@@ -593,8 +577,7 @@ GMZeroconfBrowser::BrowseCallback (AvahiServiceBrowser *b,
     if (!res) 
       PTRACE(1, "Failed to resolve service '" << name << "' :" << 
 	     avahi_strerror(avahi_client_errno(client)));
-  }
-  else {
+  } else {
 
     for (l = contacts; l && l->data; l = g_slist_next (l)) {
 
@@ -625,15 +608,7 @@ GMZeroconfBrowser::GetContacts ()
   for (l = contacts; l && l->data; l = g_slist_next (l)) {
    
     c = GM_CONTACT (l->data);
-    n = gmcontact_new ();
-    
-    n->fullname = g_strdup (c->fullname);
-    n->email = g_strdup (c->email);
-    n->url = g_strdup (c->url);
-    n->comment = g_strdup (c->comment);
-    n->software = g_strdup (c->software);
-    n->state = c->state;
-    
+    n = gmcontact_copy (c);
     ret = g_slist_append (ret, (gpointer) n);
   }
   
