@@ -43,27 +43,6 @@
 #include "manager.h"
 
 
-class GMSignalFilter : public PObject
-{
-  PCLASSINFO(GMSignalFilter, PObject);
-    
-public:
-  GMSignalFilter ();
-  
-  const PNotifier & GetReceiveHandler() const { return receiveHandler; }
-  const PNotifier & GetSendHandler() const { return sendHandler; }
-
-protected:
-  PDECLARE_NOTIFIER(RTP_DataFrame, GMSignalFilter, ReceivedPacket);
-  PDECLARE_NOTIFIER(RTP_DataFrame, GMSignalFilter, SentPacket);
-
-  PNotifier receiveHandler;
-  PNotifier sendHandler;
-
-  GtkWidget *main_window;
-};
-
-
 class GMPCSSEndpoint : public OpalPCSSEndPoint
 {
   PCLASSINFO (GMPCSSEndpoint, OpalPCSSEndPoint);
@@ -100,7 +79,13 @@ public:
   virtual void OnShowIncoming (const OpalPCSSConnection &connection);
 
 
-  //FIXME
+  /* DESCRIPTION  :  This callback is called when there is an 
+   * 		     outgoing PCSS connection and the remote endpoint is
+   * 		     ringing.
+   * 		     It triggers the appropriate timeout in order
+   * 		     to generate a ring tone.
+   * PRE          :  /
+   */
   virtual BOOL OnShowOutgoing (const OpalPCSSConnection &connection);
   
   
@@ -140,16 +125,6 @@ public:
 
   // FIXME
   virtual PString OnGetDestination (const OpalPCSSConnection &connection);  
-  
-
-  /* DESCRIPTION  :  Call back when patching a media stream.
-   *                 This function is called when a connection has created 
-   *                 a new media patch between two streams.
-   * PRE          :  /
-   */
-  virtual void OnPatchMediaStream (const OpalPCSSConnection & connection, 
-				   BOOL isSource,
-				   OpalMediaPatch & patch);
 
 
   /* DESCRIPTION  :  /
@@ -193,8 +168,6 @@ private:
   
   GMManager & endpoint;
 
-  GMSignalFilter *signal_filter;
-
   PString incomingConnectionToken; 
 
   PMutex sound_event_mutex;
